@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '5.20250321';
+$CPAN::Perl::Releases::VERSION = '5.20250413';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -319,6 +319,10 @@ our $data =
 "5.41.8" => { id => 'SHAY' },
 "5.41.9" => { id => 'HYDAHY' },
 "5.41.10" => { id => 'MAUKE' },
+"5.38.4-RC1" => { id => 'SHAY' },
+"5.40.2-RC1" => { id => 'SHAY' },
+"5.38.4" => { id => 'SHAY' },
+"5.40.2" => { id => 'SHAY' },
 };
 
 sub perl_tarballs {
@@ -388,7 +392,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 5.20250321
+version 5.20250413
 
 =head1 SYNOPSIS
 
